@@ -149,7 +149,7 @@ class Machine():
     
     @operation_mode.setter
     def operation_mode(self, operationMode):
-        self.write_register(0, OperationMode[OperationMode].value)
+        self.write_register(0, OperationMode[operationMode].value)
     
 
     @deprecated('use property')
@@ -202,7 +202,7 @@ class Zone():
 
     def __init__(self, machine, zone_id):
         self._machine = machine
-        self.zoneId = zone_id    
+        self._zone_id = zone_id    
         self.base_zone = zone_id * 256
         self._zone_state = None
         self.retrieve_zone_state()
@@ -215,7 +215,7 @@ class Zone():
         self.write_register(address, new_value)
 
     def __str__(self):
-        return "Zone with id: " + str(self.zone_id) + \
+        return "Zone with id: " + str(self._zone_id) + \
                " ZoneMode: " + str(self.get_zone_mode()) + \
                " Tacto On: " + str(self.is_tacto_on()) + \
                " Hold On: " + str(self.is_zone_hold())
@@ -471,4 +471,4 @@ class Zone():
 
     @property
     def unique_id(self):
-        return f'{str(self._machine)}_Z{self.zoneId}'
+        return f'{str(self._machine)}_Z{self._zone_id}'
